@@ -25,6 +25,7 @@ from .helpers.global_options import GlobalOptions
 from .helpers.keywords_to_options import Argument, keywords_to_options
 from .helpers.os import has_command
 from .helpers.sentry import set_scope_context_os, set_scope_tag_org, set_scope_user
+from .helpers.tee import Tee
 
 # Typing support for decorators is still in need of a lot of work:
 # https://github.com/python/mypy/issues/3157. So the current grossness
@@ -43,15 +44,19 @@ def run_subprocess(
     def impl(
         options: GlobalOptions,
         *args: Any,
+        censor_=False,
         capture_output_=False,
         silence_stderr_=True,
         input_=None,
         **kwargs: Any,
     ) -> Optional[Sequence[Optional[str]]]:
         outputs = []
+        tee = bool(options.log_dir) and not censor_
         for command in func(*args, **kwargs):
             command = keywords_to_options(command)
             options.dprint(f"exec: {shlex.join(command)}\n")
+            if tee:
+                command = Tee.tee_command(options.log_dir, command)
             result = subprocess.run(
                 command,
                 check=True,
@@ -59,9 +64,12 @@ def run_subprocess(
                 input=input_,
                 stderr=None if (capture_output_ or not silence_stderr_) else PIPE,
                 text=True,
+                shell=tee,
+                executable="/bin/bash" if tee else None,
             )
             outputs.append(result.stdout)
-            options.dprint(result.stdout)
+            if not censor_:
+                options.dprint(result.stdout)
         if capture_output_:
             return outputs
 
@@ -69,7 +77,10 @@ def run_subprocess(
 
 
 def intercept_errors(
-    patterns: ErrorPatterns = {}, *, quiet: bool = False, suppress: bool = False,
+    patterns: ErrorPatterns = {},
+    *,
+    quiet: bool = False,
+    suppress: bool = False,
 ) -> Callable[[F], F]:
     def decorate(fn: F) -> F:
         @wraps(fn)
