@@ -105,6 +105,11 @@ class SAMLClientNotFound(CliError):
         super().__init__("No valid SAML client found in PATH")
 
 
+class OfflineError(CliError):
+    def __init__(self) -> None:
+        super().__init__("You are currently offline.")
+
+
 class BotoError(CliErrorWithHint):
     def __init__(self, wrapped: "ClientError", hint: str) -> None:
         message = f"An AWS error occured!\n{str(wrapped)}"
@@ -141,6 +146,11 @@ class WrappedSubprocessError(FailedSubprocessError):
         CliError.__init__(self, "\n".join(messages), **kwargs)
 
 
+class MissingPublicKey(WrappedSubprocessError):
+    def __init__(self, wrapped, user) -> None:
+        super().__init__(wrapped, f"Does the user ({user}) exist on the instance?")
+
+
 class SamlClientNotSetup(CliErrorWithHint):
     def __init__(self) -> None:
         super().__init__(
