@@ -1,5 +1,7 @@
+import json
 import re
 import time
+from contextlib import contextmanager
 from functools import wraps
 from textwrap import dedent
 from typing import Optional
@@ -140,3 +142,28 @@ def host_to_instance(saml_client, host: str) -> str:
         raise InstanceNotFound(host)
 
     return target
+
+
+@contextmanager
+@intercept_boto_errors
+def ssm_session(saml_client, instance: str, port: int):
+    ssm_client = boto_client(saml_client, "ssm")
+    params = {
+        "Target": instance,
+        "DocumentName": "AWS-StartSSHSession",
+        "Parameters": {"portNumber": [str(port)]},
+    }
+    response = ssm_client.start_session(**params)
+    command = [
+        "session-manager-plugin",
+        json.dumps(response),
+        ssm_client.meta.region_name,
+        "StartSession",
+        "",
+        json.dumps(params),
+        ssm_client.meta.endpoint_url,
+    ]
+    try:
+        yield command
+    finally:
+        ssm_client.terminate_session(SessionId=response["SessionId"])
