@@ -1,3 +1,5 @@
+import inspect
+import logging
 import sys
 from dataclasses import dataclass, field
 from typing import ClassVar, Mapping, Optional, Type
@@ -19,7 +21,8 @@ class GlobalOptions:
 
     def dprint(self, s: str):
         if s and self.debug:
-            print(f"{s}\n", file=sys.stderr)
+            mod = inspect.getmodule(inspect.stack()[1][0])
+            logging.getLogger(mod.__name__).debug(s)
 
     def create_saml_client(self, resource: str) -> "SAMLClient":
         if not self.saml_client_type:
