@@ -18,6 +18,9 @@ def keywords_to_options(args: Sequence[Argument]) -> List[str]:
         if isinstance(arg, str):
             result.append(arg)
             continue
+        if isinstance(arg, list):
+            result.extend(keywords_to_options(arg))
+            continue
         for (key, value) in arg.items():
             if value in (False, None):
                 continue
