@@ -36,9 +36,9 @@ PARAMS: Dict[str, OrgParams] = {
             "mfa_provider": "OKTA",
             "mfa_factor_type": "push",
             "assume_role_ttl": "1h",
-            "session_ttl": "15m",
+            "session_ttl": "30m",
         },
-        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "900"},
+        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
         "profiles": {
             "prod": Profile(
                 display_name="Prod",
@@ -74,8 +74,13 @@ PARAMS: Dict[str, OrgParams] = {
         "aws_saml_url": (
             "https://dev-291131.okta.com/home/amazon_aws/0oaqlmsn7GMVgAyBK4x6/272"
         ),
-        "aws_okta_params": {},
-        "saml2aws_params": {"mfa": "Auto"},
+        "aws_okta_params": {
+            "mfa_provider": "OKTA",
+            "mfa_factor_type": "push",
+            "assume_role_ttl": "1h",
+            "session_ttl": "30m",
+        },
+        "saml2aws_params": {"mfa": "PUSH", "aws_session_duration": "1800"},
         "profiles": {
             "test": Profile(
                 display_name="Test",
@@ -117,13 +122,11 @@ def get_ssh_user() -> str:
     return get_org_params()["ssh_user"]
 
 
-def get_resource_env_var() -> Optional[str]:
+def get_resource_env_vars() -> Optional[str]:
     try:
-        env_var = get_org_params()["resource_env_var"]
-        default = os.getenv(env_var) if env_var else None
+        return ("SYM_RESOURCE", get_org_params()["resource_env_var"])
     except KeyError:
-        default = None
-    return Config.instance().get("default_resource", default)
+        return "SYM_RESOURCE"
 
 
 def get_profile(resource: str) -> Profile:
