@@ -18,7 +18,7 @@ from ..errors import (
     TargetNotConnected,
     WrappedSubprocessError,
 )
-from ..helpers.boto import send_ssh_key
+from ..helpers.boto import send_ssh_key, ssm_session
 from ..helpers.config import Config, SymConfigFile
 from ..helpers.contexts import push_envs
 from ..helpers.keywords_to_options import keywords_to_options
@@ -68,8 +68,14 @@ def ssh_args(client, instance, port) -> tuple:
         "p": str(port),
         "F": str(ssh_config),
         "l": get_ssh_user(),
+        "v": client.debug,
     }
-    return ("ssh", instance, opts)
+    return (
+        "ssh",
+        instance,
+        opts,
+        f"-o HostKeyAlias={instance}",
+    )
 
 
 @run_subprocess
@@ -106,7 +112,7 @@ def start_ssh_session(
     command: Sequence[str] = [],
     wrap: bool = True,
 ):
-    ensure_ssh_key(client, instance, port, args=args)
+    ensure_ssh_key(client, instance, port)
     try:
         _start_ssh_session(client, instance, port, *args, *command)
     except CalledProcessError as err:
@@ -143,8 +149,21 @@ def ensure_ssh_key(
     args: Sequence[str] = [],
 ):
     ssh_key, ssh_config = ssh_key_and_config(client)
-
     sym_cmd = f"PYTHONUNBUFFERED=1 sym {client.cli_options} ssh-session {client.resource} --instance %h --port %p"
+    ssh_cp = SymConfigFile(file_name="ssh/cp/.keep")
+
+    if client.debug:
+        mux_config = f"""
+            ControlMaster no
+        """
+
+    else:
+        mux_config = f"""
+            ControlMaster auto
+            ControlPersist 15m
+            ControlPath {ssh_cp.path.parent}/%r@%h:%p
+        """
+
     # fmt: off
     ssh_config.put(dedent(  # Ensure the SSH Config first, always
         f"""
@@ -158,10 +177,12 @@ def ensure_ssh_key(
             ChallengeResponseAuthentication no
             GSSAPIAuthentication no
             ProxyCommand sh -c "{sym_cmd} || exit $?"
+            {mux_config.strip()}
         """
     ))
     # fmt: on
 
+    ssh_cp.mkparents()
     maybe_gen_ssh_key(client)
 
     if Config.check_instance_ttl(instance, ttl):
@@ -183,20 +204,19 @@ def ensure_ssh_key(
 
 def start_tunnel(client, instance: str, port: int):
     SymGroup.reset_tees()
-    with push_envs(client.get_creds()):
-        os.execvp(
-            "aws",
-            keywords_to_options(
-                [
-                    "aws",
-                    "ssm",
-                    "start-session",
-                    {
-                        "target": instance,
-                        "document_name": "AWS-StartSSHSession",
-                        "parameters": f"portNumber={port}",
-                    },
-                ]
-            ),
-        )
+    client.dprint("execing aws ssm")
 
+    def handler(signum, frame):
+        devnull = os.open(os.devnull, os.O_WRONLY)
+        os.dup2(devnull, sys.stdout.fileno())
+        # Set error state on session end.
+        # If the connection was actually successful,
+        # the parent thread will re-set a success state.
+        # This is the only reliable way to avoid error
+        # loops with Ansible due to missing SSH public keys.
+        Config.touch_instance(instance, error=True)
+
+    signal(SIGPIPE, handler)
+
+    with ssm_session(client, instance, port) as command:
+        client.exec(*command)
