@@ -73,11 +73,13 @@ class SymGroup(Group):
             # Don't register exit handler so exceptions are teed.
             # Instead, __del__ will be called when the program exits.
             self.__class__.tees.extend((TeeStdOut(log_dir), TeeStdErr(log_dir)))
+            logging_filename = Tee.path_for_fd(log_dir, "logging")
+        else:
+            logging_filename = None
 
-            if ctx.params.get("debug"):
-                logging.basicConfig(
-                    level=logging.DEBUG, filename=Tee.path_for_fd(log_dir, "logging")
-                )
+        if ctx.params.get("debug"):
+            logging.basicConfig(level=logging.DEBUG, filename=logging_filename)
+            logging.getLogger("segment").setLevel(logging.WARNING)
 
         return super().invoke(ctx)
 
