@@ -4,15 +4,18 @@ from pathlib import Path
 from typing import Final, Iterator, Optional, Tuple
 
 from ..decorators import intercept_errors, require_bins, run_subprocess
-from ..errors import FailedSubprocessError, UnavailableResourceError
+from ..errors import FailedSubprocessError, SamlClientNotSetup, UnavailableResourceError
 from ..helpers.config import Config, SymConfigFile
-from ..helpers.constants import Saml2AwsNoRoles
+from ..helpers.constants import Saml2AwsNoCreds, Saml2AwsNoRoles
 from ..helpers.contexts import push_env
 from ..helpers.keywords_to_options import Argument, Options, keywords_to_options
 from ..helpers.params import Profile, get_saml2aws_params
 from .saml_client import SAMLClient
 
-ErrorPatterns = {Saml2AwsNoRoles: UnavailableResourceError}
+ErrorPatterns = {
+    Saml2AwsNoRoles: UnavailableResourceError,
+    Saml2AwsNoCreds: SamlClientNotSetup,
+}
 
 
 class Saml2Aws(SAMLClient):
