@@ -106,7 +106,8 @@ class SAMLClient(ABC):
 
     def ensure_session(self, force=False):
         if not self._session_exists:
-            self._ensure_session(force=force)
+            self.dprint(f"ensuring session, force={force}")
+            self._ensure_session(force=force or self._creds_expiring())
             self._session_exists = True
 
     def ensure_config(self) -> ConfigParser:
@@ -149,24 +150,23 @@ class SAMLClient(ABC):
             url = urlsplit(url).path[1:]
         return url
 
-    def get_creds(self):
-        output = self.exec("env", capture_output_=True)[-1]
-        env_vars = re.findall(r"([\w_]+)=(.+)\n", output)
-        return {
-            k: v
-            for k, v in env_vars
-            if k
-            in (
-                "AWS_REGION",
-                "AWS_ACCESS_KEY_ID",
-                "AWS_SECRET_ACCESS_KEY",
-                "AWS_SESSION_TOKEN",
-                "AWS_SECURITY_TOKEN",
-                "AWS_CREDENTIAL_EXPIRATION",
-            )
-        }
+    @property
+    def _cred_env_vars(self):
+        return (
+            "AWS_REGION",
+            "AWS_ACCESS_KEY_ID",
+            "AWS_SECRET_ACCESS_KEY",
+            "AWS_SESSION_TOKEN",
+            "AWS_SECURITY_TOKEN",
+            "AWS_CREDENTIAL_EXPIRATION",
+        )
 
-    def _creds_expiring(self, buffer=timedelta(minutes=10)):
+    def get_creds(self):
+        output = self._exec("env", capture_output_=True, censor_=True)[-1]
+        env_vars = re.findall(r"([\w_]+)=(.+)\n", output)
+        return {k: v for k, v in env_vars if k in self._cred_env_vars}
+
+    def _creds_expiring(self, buffer=timedelta(minutes=2)):
         if (expires := self.get_creds().get("AWS_CREDENTIAL_EXPIRATION")) :
             parsed = datetime.fromisoformat(expires)
             remaining = parsed - datetime.now(parsed.tzinfo)
@@ -175,7 +175,7 @@ class SAMLClient(ABC):
         return False
 
     def write_creds(self, *, path: Path, profile: str):
-        if self._creds_expiring():
+        if self._creds_expiring(buffer=timedelta(minutes=5)):
             self._ensure_session(force=True)
 
         creds = self.get_creds()
