@@ -7,10 +7,10 @@ import click
 import pytest
 from _pytest.monkeypatch import MonkeyPatch
 
-from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.helpers import boto
 from sym.cli.helpers.config import Config
 from sym.cli.helpers.contexts import push_env
+from sym.cli.helpers.global_options import GlobalOptions
 from sym.cli.saml_clients import aws_profile
 from sym.cli.saml_clients.saml_client import SAMLClient
 from sym.cli.sym import sym as click_command
@@ -74,6 +74,10 @@ def _subprocess_friendly_asserter(args: Tuple[Type[P], Sandbox]) -> None:
     monkeypatch.setattr(SAMLClient, "check_is_setup", lambda self: ...)
 
     with sandbox.push_xdg_config_home(), sandbox.push_exec_path(), capture_command():
+        outputs = [
+            "AWS_REGION=foobar\nAWS_FOOBAR=baz\nAWS_OKTA_SESSION_EXPIRATION=1600494616\n"
+        ] * 2
+        capture_command.enqueue_outputs(*outputs)
         Config.instance()["org"] = "sym"
         with click.Context(click_command) as ctx:
             ctx.ensure_object(GlobalOptions)
