@@ -16,10 +16,12 @@ pytestmark = [
 def test_saml2aws(
     test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
 ) -> None:
+    capture_command.enqueue_outputs("AWS_REGION=foobar\nAWS_FOOBAR=baz")
     with test_context(debug=False) as saml2aws:
         with capture_command():
             saml2aws.exec("aws", "ssm", "start-session", target="i-0123456789abcdef")
     capture_command.assert_command(
+        f"saml2aws --config {saml2aws.config_file} --idp-account sym --skip-prompt exec -- env",
         f"saml2aws --config {saml2aws.config_file} --idp-account sym --skip-prompt login",
         f"saml2aws --config {saml2aws.config_file} --idp-account sym --skip-prompt exec -- 'aws ssm start-session --target i-0123456789abcdef'",
     )
@@ -28,7 +30,9 @@ def test_saml2aws(
 def test_saml2aws_get_creds(
     test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
 ) -> None:
-    capture_command.enqueue_outputs("", "AWS_REGION=foobar\nAWS_FOOBAR=baz")
+    capture_command.enqueue_outputs(
+        "AWS_REGION=foobar\nAWS_FOOBAR=baz", "", "AWS_REGION=foobar\nAWS_FOOBAR=baz"
+    )
     with test_context(debug=False) as saml2aws:
         with capture_command():
             assert saml2aws.get_creds() == {"AWS_REGION": "foobar"}
@@ -37,10 +41,12 @@ def test_saml2aws_get_creds(
 def test_saml2aws_debug(
     test_context: TestContextFixture[Saml2Aws], capture_command: CaptureCommand
 ) -> None:
+    capture_command.enqueue_outputs("AWS_REGION=foobar\nAWS_FOOBAR=baz")
     with test_context(debug=True) as saml2aws:
         with capture_command():
             saml2aws.exec("env")
     capture_command.assert_command(
+        f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym --skip-prompt exec -- env",
         f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym --skip-prompt login",
         f"saml2aws --verbose --config {saml2aws.config_file} --idp-account sym --skip-prompt exec -- env",
     )
@@ -51,6 +57,7 @@ def test_saml2aws_multi_threads(subprocess_friendly_asserter) -> None:
     with sandbox.push_xdg_config_home():
         config_file = SymConfigFile(resource="test", file_name="saml2aws.cfg")
     commands = (
+        f"saml2aws --config {config_file} --idp-account sym --skip-prompt exec -- env",
         f"saml2aws --config {config_file} --idp-account sym --skip-prompt login",
         f"saml2aws --config {config_file} --idp-account sym --skip-prompt exec -- env",
     )
