@@ -32,7 +32,7 @@ def test_resources(click_setup):
         assert result.output == "test (Test)\n"
 
 
-def test_exec(click_setup):
+def test_exec(click_setup, saml_client):
     with click_setup() as runner:
         result = runner.invoke(click_command, ["exec", "test", "--", "aws"])
         assert result.exit_code == 0
